@@ -24,11 +24,10 @@ pyutilib.component.core.PluginGlobals.pop_env()
 try:
     import pkg_resources
     #
-    # Load modules associated with Plugins that are defined in 
+    # Load modules associated with Plugins that are defined in
     # EGG files.
     #
     for entrypoint in pkg_resources.iter_entry_points('coopr.opt'):
         plugin_class = entrypoint.load()
 except Exception, err:
-    print "Error loading coopr.opt entry points:",str(err)
-
+    print "Error loading coopr.opt entry points:",str(err),' entrypoint="%s"' % str(entrypoint)
