@@ -14,8 +14,7 @@ import opt_config
 
 from error import *
 from convert import *
-from solver import *
+from solvers import *
 from results import *
 from problem import *
 from formats import *
-
