@@ -12,7 +12,7 @@
 __all__ = []
 
 from manager import *
-from solver import *
+from async_solver import *
 from pyutilib.component.core import alias
 
 
@@ -54,4 +54,3 @@ class SolverManager_Serial(AsynchronousSolverManager):
         if len(self._ah_list) > 0:
             return self._ah_list.pop()
         return ActionHandle(error=True, explanation="No queued evaluations available in the 'local' solver manager, which only executes solvers synchronously")
-
