@@ -6,6 +6,8 @@ from pyutilib.misc import Bunch
 from pyutilib.enum import EnumValue, Enum
 import StringIO
 import copy
+import string
+import math
 
 ScalarType = Enum('int', 'time', 'string', 'float', 'enum', 'undefined')
 
@@ -83,12 +85,47 @@ class ScalarData(object):
             return ignore
         if option.ignore_time and str(self.scalar_type) == str(ScalarType.time):
             return ignore
+
         value = self.yaml_fix(self.get_value())
+
         if value is pyutilib.math.infinity:
             value = '.inf'
         elif value is - pyutilib.math.infinity:
             value = '-.inf'
-        if not option.schema and self.description is None and self.units is None:
+
+        # the following is specialized logic for handling variable and constraint maps - which
+        # are dictionaries of dictionaries, with at a minimum an "id" element per sub-directionary.
+        # TODO: This logic should be moved into a separate class for these maps...
+        if isinstance(value, dict) and (len(value) > 0) and isinstance(value[value.keys()[0]], dict) and ("Id" in value[value.keys()[0]]):
+            id_dict_map = {}
+            id_name_map = {} # the name technically could be an integer or float - so convert prior to printing (see code below)
+            id_nonzeros_map = {} # are any of the non-id entries are non-zero?
+            entries_to_print = False
+
+            for entry_name, entry_dict in value.iteritems():
+                entry_id = entry_dict["Id"]
+                id_name_map[entry_id] = entry_name
+                id_dict_map[entry_id] = entry_dict
+                id_nonzeros_map[entry_id] = False # until proven otherwise
+                for attr_name, attr_value in entry_dict.iteritems():
+                    if (attr_name != "Id") and (attr_value != 0):
+                        id_nonzeros_map[entry_id] = True
+                        entries_to_print = True
+
+            if entries_to_print is True:
+                print >>ostream, ""
+                for entry_id in sorted(id_dict_map.keys()):
+                    if id_nonzeros_map[entry_id] is True:
+                        print >>ostream, prefix+str(id_name_map[entry_id])+":"
+                        entry_dict = id_dict_map[entry_id]
+                        for attr_name, attr_value in entry_dict.iteritems():
+                            if isinstance(attr_value,float) and (math.floor(attr_value) == attr_value):
+                                attr_value = int(attr_value)
+                            print >>ostream, prefix+"  "+string.capitalize(attr_name)+": "+str(attr_value)
+            else:
+                print >>ostream, "No nonzero values"
+
+        elif not option.schema and self.description is None and self.units is None:
             print >>ostream, value
         else:
             print >>ostream, ""
@@ -108,7 +145,7 @@ class ScalarData(object):
         if not isinstance(val,basestring):
             return val
         return val.replace(':','\\x3a')
-            
+
     def load(self, repn):
         if type(repn) is dict:
             for key in repn:
@@ -150,11 +187,11 @@ class ListContainer(object):
 
     def __setattr__(self,name,val):
         if name == "__class__":
-           self.__class__ = val
-           return
+            self.__class__ = val
+            return
         if name[0] == "_":
-           self.__dict__[name] = val
-           return
+            self.__dict__[name] = val
+            return
         if len(self) == 0:
             self.add()
         setattr(self._list[0], name, val)
@@ -208,7 +245,7 @@ class ListContainer(object):
 
 
 #
-# This class manages use-defined attributes in 
+# This class manages use-defined attributes in
 # a dictionary.  Attributes are translated into
 # a string where '_' is replaced by ' ', and where the
 # first letter is capitalized.
@@ -242,11 +279,11 @@ class MapContainer(dict):
 
     def __setattr__(self,name,val):
         if name == "__class__":
-           self.__class__ = val
-           return
+            self.__class__ = val
+            return
         if name[0] == "_":
-           self.__dict__[name] = val
-           return
+            self.__dict__[name] = val
+            return
         self._active=True
         tmp = self._convert(name)
         if tmp not in self:
@@ -271,7 +308,10 @@ class MapContainer(dict):
         self._set_value(tmp,val)
 
     def _set_value(self, name, val):
-        dict.__getitem__(self, name).value = val
+        if isinstance(val,ListContainer) or isinstance(val,MapContainer):
+            dict.__setitem__(self, name, val)
+        else:
+            dict.__getitem__(self, name).value = val
 
     def __getitem__(self, name):
         tmp = self._convert(name)
@@ -366,7 +406,7 @@ class MapContainer(dict):
 
     def __getstate__(self):
         return copy.copy(self.__dict__)
- 
+
     def __setstate__(self, state):
         self.__dict__.update(state)
 
@@ -396,4 +436,3 @@ if __name__ == '__main__':
     print d.i._active, d.j._active
     d.j.add()
     print d.i._active, d.j._active
-
