@@ -60,7 +60,6 @@ class SolutionMap(MapContainer):
         return item.value
 
     def _set_value(self, name, val):
-        #print "_set_value",name,val
         if isinstance(name,basestring):
             self.declare_item(name)
         elif type(name) is int:
@@ -68,7 +67,6 @@ class SolutionMap(MapContainer):
         if type(name) is int:
             name = self._names[name-1]
         dict.__getitem__(self, name).value = as_number(val)
-        #print "_set_value",dict.__getitem__(self, name).value
 
     def declare(self, name, **kwds):
         if type(name) is int:
@@ -90,7 +88,6 @@ class SolutionMap(MapContainer):
                 id = len(self._names)
         if name in self:
             return
-        #print "DECL3",name
         MapContainer.declare(self, name, value=MapContainer())
         dict.__getitem__(self, name).id = id
         self._names[id] = name
@@ -110,9 +107,9 @@ class SolutionMap(MapContainer):
                 # the name, which is fine. it just requires a bit of ugliness in
                 # the string splitting process.
                 if name.count("]") == 2:
-                   rest = pieces[2]
+                    rest = pieces[2]
                 else:
-                   rest = pieces[1]
+                    rest = pieces[1]
                 # we're always taking the first part of the name,
                 # so even in the two (or greater) dimensional case
                 # such as "x((a,b))", the first piece is what we want.
@@ -121,11 +118,9 @@ class SolutionMap(MapContainer):
                 for i in xrange(len(tokens)):
                     tokens[i] = as_number(tokens[i])
                 try:
-                    #print "GETTING",varname
                     var = self.__dict__[varname]
                     #var = dict.__getitem__(self, varname)
                 except Exception, err:
-                    #print "SETTING",varname
                     self.__dict__[varname]={}
                     var = self.__dict__[varname]
                     #dict.__setitem__(self, varname, {})
@@ -133,15 +128,14 @@ class SolutionMap(MapContainer):
                 if len(tokens) == 1:
                     var[ tokens[0] ] = dict.__getitem__(self, name)
                 else:
-                    #print "SETTING",varname,tokens,tuple(tokens)
                     var[ tuple(tokens) ] = dict.__getitem__(self, name)
             #else:
                 #self.__dict__[name]=dict.__getitem__(self, name)
 
     def _convert(self, name):
-        if isinstance(name, basestring):
-            name = name.replace('(','[')
-            name = name.replace(')',']')
+
+        # conversion disabled - originally only munged names by
+        # replacing () for []. that functionality is no longer needed.
         return name
 
     def _repn_(self, option):
@@ -212,11 +206,19 @@ class Solution(MapContainer):
         self.declare('message')
 
         self.declare('objective', value=SolutionMap(sparse=False), active=False)
-        self.declare('variable', value=SolutionMap(), active=False)
+        self.declare('variable', value={})
         self.declare('constraint', value=SolutionMap(), active=False)
 
         self._option = default_print_options
 
+    def load(self, repn):
+        # delete key from dictionary, call base class load, handle variable loading.
+        if repn.has_key("Variable"):
+            var_dict = repn["Variable"]
+            del repn["Variable"]
+            self.variable = var_dict
+        MapContainer.load(self,repn)
+
 
 class SolutionSet(ListContainer):
 
@@ -269,7 +271,6 @@ class SolutionSet(ListContainer):
         # Note: we ignore the first element of the repn list, since
         # it was generated on the fly by the SolutionSet object.
         #
-        for data in repn[1:]:
+        for data in repn[1:]: # repn items 1 through N are individual solutions.
             item = self.add()
             item.load(data)
-
